package cn.com.infosec.mobile.android.cert;

import android.support.annotation.Keep;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.Base64;
import cn.com.infosec.mobile.android.xlog.XLog;
import java.io.ByteArrayInputStream;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;

@Keep
public class InfosecCert {
   @Keep
   private native boolean importCertNative(String var1, String var2);

   @Keep
   private native boolean importPfxCertNative(String var1, String var2, String var3);

   @Keep
   private native String[] createP10DoubleNative(String var1, String var2, String var3, int var4, boolean var5);

   @Keep
   private native boolean importDoubleCertNative(String var1, String var2, String var3, String var4, String var5, String var6);

   @Keep
   private native String[] getCertNative(String var1, int var2);

   @Keep
   private native String[] getCertsNative();

   @Keep
   private native String[] getAliasNative();

   @Keep
   private native String getPublicKeyNative(String var1);

   @Keep
   private native byte[] exportPFXNative(String var1, String var2);

   @Keep
   private native boolean checkCertExistNative(String var1);

   @Keep
   private native boolean clearDataNative(String var1);

   @Keep
   private native byte[] getP10RequestPublicKeyNative(String var1);

   @Keep
   private native String[] genP10PubKeyNative(String var1, int var2, int var3, String var4, String var5);

   @Keep
   private native byte[] hashNative(String var1, byte[] var2);

   @Keep
   private native byte[] hmacNative(byte[] var1, String var2, byte[] var3);

   @Keep
   private native byte[] symmEncryptNative(byte[] var1, byte[] var2, int var3, int var4, int var5, boolean var6, byte[] var7);

   public String[] createP10DoubleCert(@NonNull String DN, @NonNull String PIN, @NonNull String sigAlgorithm, int keyLength) {
      if (!TextUtils.isEmpty(DN) && !TextUtils.isEmpty(PIN) && !TextUtils.isEmpty(sigAlgorithm) && keyLength != 0) {
         boolean var5 = sigAlgorithm.endsWith("RSA");
         boolean var6;
         if (1024 != keyLength) {
            var6 = true;
         } else {
            var6 = false;
         }

         var5 &= var6;
         if (2048 != keyLength) {
            var6 = true;
         } else {
            var6 = false;
         }

         if (var5 & var6) {
            XLog.d("createP10: 算法与密钥长度不符");
            return null;
         } else {
            var5 = sigAlgorithm.endsWith("SM2");
            if (256 != keyLength) {
               var6 = true;
            } else {
               var6 = false;
            }

            if (var5 & var6) {
               XLog.d("createP10: 算法与密钥长度不符");
               return null;
            } else {
               return this.createP10DoubleNative(DN, PIN, sigAlgorithm, keyLength, false);
            }
         }
      } else {
         XLog.d("createP10: 参数为空，无法创建P10");
         return null;
      }
   }

   public boolean importCert(@NonNull String base64cert, @NonNull String alias) {
      return this.importCertNative(base64cert, alias);
   }

   public boolean importDoubleCert(@NonNull String signCert, @NonNull String encCert, @NonNull String encodedPriKey, @NonNull String encodedSecretKey, @NonNull String alias, @NonNull String PIN) {
      return this.importDoubleCertNative(signCert, encCert, encodedPriKey, encodedSecretKey, alias, PIN);
   }

   public X509Certificate getCert(@NonNull String alias) {
      String[] var3;
      if ((var3 = this.getCertNative(alias, 0)) != null && var3.length > 0) {
         String var4 = var3[0];

         try {
            return (X509Certificate)CertificateFactory.getInstance("X.509").generateCertificate(new ByteArrayInputStream(Base64.decode(var4, 0)));
         } catch (CertificateException var2) {
            var2.printStackTrace();
            XLog.d("getCert: 序列化证书失败" + var2);
            return null;
         }
      } else {
         return null;
      }
   }

   public X509Certificate[] getCerts() {
      String[] var7;
      if ((var7 = this.getCertsNative()) != null && var7.length > 0) {
         X509Certificate[] var1 = new X509Certificate[var7.length];

         CertificateException var10000;
         label44: {
            CertificateFactory var8;
            boolean var10001;
            try {
               var8 = CertificateFactory.getInstance("X.509");
            } catch (CertificateException var6) {
               var10000 = var6;
               var10001 = false;
               break label44;
            }

            CertificateFactory var2 = var8;
            int var3 = 0;

            while(true) {
               int var9;
               int var10;
               try {
                  var9 = var3;
                  var10 = var7.length;
               } catch (CertificateException var5) {
                  var10000 = var5;
                  var10001 = false;
                  break;
               }

               if (var9 >= var10) {
                  return var1;
               }

               try {
                  var1[var3] = (X509Certificate)var2.generateCertificate(new ByteArrayInputStream(Base64.decode(var7[var3], 0)));
               } catch (CertificateException var4) {
                  var10000 = var4;
                  var10001 = false;
                  break;
               }

               ++var3;
            }
         }

         var10000.printStackTrace();
         XLog.d("getCerts: 序列化证书失败");
         return null;
      } else {
         XLog.d("getCerts: 本地证书获取失败");
         return null;
      }
   }

   public String[] getAlias() {
      return this.getAliasNative();
   }

   public String getPublicKey(@NonNull String alias) {
      if (TextUtils.isEmpty(alias)) {
         return null;
      } else {
         return !this.checkCertExist(alias) ? null : this.getPublicKeyNative(alias);
      }
   }

   public boolean checkCertExist(@NonNull String alias) {
      return TextUtils.isEmpty(alias) ? false : this.checkCertExistNative(alias);
   }

   public String getCertInfo(@NonNull String alias, int field) {
      return this.getCertInfoNative(alias, field);
   }

   public String[] genP10PubKey(String PIN, int keyLen, int keyType, String sessionId, String serverPublicKey) {
      return this.genP10PubKeyNative(PIN, keyLen, keyType, sessionId, serverPublicKey);
   }

   public boolean clearData(@NonNull String alias) {
      return this.clearDataNative(alias);
   }

   @Keep
   public native String createP10Native(String var1, String var2, String var3, int var4, boolean var5);

   @Keep
   public native String getEncryptCertNative(String var1);

   @Keep
   public native byte[] getPublicKeyWithCertNative(String var1);

   @Keep
   public native boolean deleteCertNative(String var1);

   @Keep
   public native boolean changePINNative(String var1, String var2, String var3);

   @Keep
   public native int checkPINNative(String var1, String var2);

   @Keep
   public native String getCertInfoNative(String var1, int var2);

   @Keep
   public native byte[] certEncryptDataNative(String var1, byte[] var2);

   @Keep
   public native byte[] certDecryptCipherNative(String var1, String var2, byte[] var3, boolean var4);

   @Keep
   public native byte[] sm2EncryptDataNative(byte[] var1, byte[] var2);
}
